#
# spec file for package dice
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dice
Version:        0.7.3
Release:        5.3
%define mod_name dice
%define mod_full_name %{mod_name}-%{version}
%define rb_build_versions %{rb_default_ruby}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{rubygem abstract_method >= 1.2.1}
BuildRequires:  %{rubygem bundler}
BuildRequires:  %{rubygem cheetah >= 0.4.0}
BuildRequires:  %{rubygem gem2rpm}
BuildRequires:  %{rubygem gli >= 2.11.0}
BuildRequires:  %{rubygem inifile >= 2.0.2}
BuildRequires:  %{rubygem json >= 1.8.0}
BuildRequires:  %{rubygem rice}
BuildRequires:  %{ruby}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ruby-devel
BuildRequires:  ruby-macros >= 5
BuildRequires:  update-alternatives

# Disable autogenerating "Requires:" headers for bundled gems.
%define __requires_exclude ^rubygem
Requires:       ruby >= 2.0
Requires:       ruby-solv
Url:            http://www.suse.com
Source0:        %{mod_full_name}.gem
Source1:        %{mod_name}-rpmlintrc
Source2:        gem2rpm.yml
Summary:        Light Weight Image Build System
License:        GPL-3.0
Group:          Development/Languages/Ruby

%description
Given there is the need to build a kiwi appliance for a customer,
one wants to keep track of the updates from the distribution and
software vendors according to the components used in the appliance.
This leads to a regular rebuild of that appliance which should be
automatically triggered whenever the repository which stores all
the software packages has changed. With Dice there is a tool which
automatically builds all appliances stored in a directory

%prep

%build

%install
# Install the Ruby source
%gem_install \
  --symlink-binaries \
  --doc-files="COPYING key" \
  -f

# Change to ruby gem dir
pushd %{buildroot}%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}

# Build CPP extensions
( cd lib/semaphore && ruby ./extconf.rb && make && rm -f semaphore.o )

# Bundle dependencies
cat > Gemfile <<EOT
gem "cheetah", ">= 0.4.0"
gem "gli", ">= 2.11.0"
gem "abstract_method", ">= 1.2.1"
%if %suse_version <= 1310
gem "json", ">= 1.8.0"
%endif
gem "inifile", ">= 2.0.2"
EOT

mkdir -p vendor/cache
cp %{_libdir}/ruby/gems/%{rb_ver}/cache/*.gem vendor/cache

bundle install --standalone --local

rm -rf vendor .bundle Gemfile Gemfile.lock

# Delete devel source
( cd lib/semaphore && rm -f semaphore.cpp Makefile extconf.rb )

# Move bash completion
mkdir -p %{buildroot}/etc/bash_completion.d
mv completion/dice.sh %{buildroot}/etc/bash_completion.d

popd

# Adapt the binary
# Here we do a surgery on the binary to actually load the bundled gems.
# This is a hack, but it can't be done anywhere else because the binary
# is generated during gem install.
sed -i '/gem/i \
Gem.path.unshift("%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/bundle/ruby/%{rb_ver}")

' %{buildroot}/usr/bin/dice.ruby*-%{version}

# Convert duplicate files to symlinks
%fdupes -s %{buildroot}

%gem_packages
%config /etc/bash_completion.d/dice.sh

%changelog
* Wed Jul 29 2015 ms@suse.de
- Fixed job prepare_build
  The method glob deletes old builds from tmp. What sounds
  like a good idea is a bad one because when multiple job
  runs in parallel this breaks the other jobs. That's
  because depending on the selected build system and setup
  tmp might be a shared location
* Tue Jul 28 2015 ms@suse.de
- Fixed calculateDigest
  The calculation of the recipe digest is based on the data which
  build the image description. However if people use a repository
  as part of the image description it should not be taken into
  consideration, because a solver operation will find potential
  repository changes. Therefore the list of files and directories
  belonging to an image description is limited to the top level
  entries and the recursive search for the optioal overlay
  root directory
* Tue Jul 28 2015 ms@suse.de
- Fixed comps download and test
* Tue Jul 28 2015 ms@suse.de
- Follow up fix to support yum groups
  yum group names are prefixed with group: not with pattern:
* Sat Jul 25 2015 ms@suse.de
- Added support for this:// kiwi uri type
* Mon Jul 20 2015 ms@suse.de
- Added --skip-missing option
  Allows to skip packages for the solver operation if they
  could not be found in the repositories. This is useful
  if packages are only relevant for certain profiles of the
  kiwi configuration. Dice always solves over all packages
  listed in the configuration
* Mon Jul 20 2015 ms@suse.de
- Version 0.7.3
* Mon Jul 20 2015 ms@suse.de
- Fixed kiwi URI obs resolver
  prevent double slashes in output URL
* Mon Jul 20 2015 ms@suse.de
- Added support for yum groups in solver
  libsolv provides a comp2solv parser which allows to read yum
  groups (comps) files. This allows to let satsolver use yum
  groups for building rhel images
* Mon Jul 20 2015 ms@suse.de
- Fixed packaging
  missing ruby-solv requirement, and broken binary patch to
  adapt the gem search path
* Sun Jul 19 2015 ms@suse.de
- Disable ruby internal buffering for build log
* Thu Jul 16 2015 ms@suse.de
- Version 0.7.2
* Thu Jul 16 2015 ms@suse.de
- Use unique tmp names for building
* Thu Jul 16 2015 ms@suse.de
- Bind mount docker host tmp dir for building
  It should be avoided to produce big data in the docker storage
  backend. We might easily run out of space
* Thu Jul 16 2015 ms@suse.de
- Stick to the naming conventions of docker
  Use the tag name 'latest' to identify the most recent image
* Thu Jul 16 2015 ms@suse.de
- Fixed calling commands passed to docker run
  let a shell process evaluate the given parameters
* Wed Jul 15 2015 ms@suse.de
- Added support for plain docker build system
  The buildsystem will pull the opensuse/kiwi image from dockerhub
  to establish a build environment
* Tue Jul 14 2015 ms@suse.de
- Refactor job command invokation
  Make sure the basic access to the buildsystem is provided by
  the buildsystem factory and not created as part of the job.
  This allows to run job commands within a buildservice by the
  nature of the buildservice and not hard coded to the use
  of ssh. This change has been in preparation to add a native
  docker build service class
* Mon Jun  8 2015 ms@suse.de
- Update README
  due to the use of the latest packaging tools for ruby modules the
  package was renamed to follow the guidelines. Formerly 'dice' is
  now ruby<version>-rubygem-dice-<version>.<arch>
* Tue May 19 2015 ms@suse.de
- Version 0.6.1
* Tue May 19 2015 ms@suse.de
- Adapt package spec, remove recipes
* Tue May 19 2015 ms@suse.de
- Delete recipes
  The recipes are basically duplicates from the JeOS descriptions
  provided by kiwi-templates. Now that the kiwi-templates are
  prepared for dice (provides a Vagrantfile) we refer to one
  central place instead of duplicating descriptions
* Tue May 19 2015 ms@suse.de
- Update README
  Change default provider setup to docker. This allows to directly
  refer to the kiwi-templates which contains all dice configs to
  build contained. In addition using docker is much faster than
  virtualbox. Thus I recommend this system
* Sun May 17 2015 ms@suse.de
- Switched to gem2rpm way of creating the package
* Fri Apr 10 2015 ms@suse.de
- Make sure a default provider is set for vagrant
  dice takes the value VAGRANT_DEFAULT_PROVIDER from the
  environment and if not set it is set to 'docker'. the
  parameter will be passed as --provider option to the
  vagrant calls
* Tue Apr  7 2015 ms@suse.de
- Fixed handling of relative repo source paths
  Relative source paths can be set relative to the image
  description. Inside of the container the image description
  is mapped below /vagrant. If the relative path is leaving
  the image description directory it is in the user's
  responsibility to map the repo to the right place inside
  of the container so that the relative path points correctly
  to the repository. This fixes #7
* Tue Mar 24 2015 ms@suse.de
- Support legacy obs type pointing to yast style repo
* Tue Mar 24 2015 ms@suse.de
- Update dist url's in example recipes
  Unfortunately kiwi can only deal well with distro repos if they
  are of type yast2. This is because in case of using the rpm-md
  version the pattern information is missing. Thus we switch back
  to the yast2 url
* Tue Mar 24 2015 ms@suse.de
- Add use of pattern data for rpm-md repos
  In the buildservice an rpm-md repo can provide suse style
  pattern information. If present we make use of them to form
  the solvable
* Tue Mar 24 2015 ms@suse.de
- Fixed translation of obs repo to http repo
  Use the correct URL schema to form an http url containing the
  obs project names. The obs redirector takes are for redirecting
  to the correct repo location
* Tue Mar 24 2015 ms@suse.de
- Update recipe template repositories
  Use the correct project layout for describing an obs repo
* Tue Mar 24 2015 ms@suse.de
- Support obs url type for update repos
  The url matcher now also supports obs url types
  of the type obs://update/<distro>
* Tue Mar 24 2015 ms@suse.de
- Make sure potential kiwi lock file is removed
  Prior to building the prepare_build method also removes
  stale kiwi init lock file from /var/lock
* Tue Mar 24 2015 ms@suse.de
- Added update repo to 13.1 example recipe
* Fri Mar 20 2015 ms@suse.de
- Prevent halt() from being called multiple times
  In case of an exception the global exception handler will
  call the cleanup correctly. Thus there is no need to actively
  halt the buildsystem if the next call is a raise
* Fri Mar 20 2015 ms@suse.de
- Support dice build option --kiwiprofile
  If specified the option will hand over the value to the
  contained kiwi call as --add-profile option. This fixes #6
* Wed Mar 18 2015 ms@suse.de
- Update suse-13.1-JeOS recipe
  deprecated vagrant option -privileged, replaced by --privileged
* Tue Mar 10 2015 ms@suse.de
- Delete invalid dot graph
* Tue Mar 10 2015 ms@suse.de
- More robust inheritance for connection classes
  Connection sub classes should not require to call super
  in order to run the constructor from the base class. It's
  more robust to let the base class constructor call a post
  initialize method which can be specialized in the sub class
  when required
* Tue Mar 10 2015 ms@suse.de
- More robust inheritance for buildsystem classes
  BuildSystem sub classes should not require to call super
  in order to run the constructor from the base class. It's
  more robust to let the base class constructor call a post
  initialize method which can be specialized in the sub class
  when required
* Tue Mar 10 2015 ms@suse.de
- More robust inheritance for repository classes
  Repository sub classes should not require to call super
  in order to run the constructor from the base class. It's
  more robust to let the base class constructor call a post
  initialize method which can be specialized in the sub class
  when required
* Mon Mar  9 2015 ms@suse.de
- Update project url
* Fri Mar  6 2015 ms@suse.de
- Cleanup use of default values
  Use a symbol as default buildhost indicator to avoid conflicts
  with buildhost names. In addition make sure that all constant
  values are stored at the same place
* Fri Mar  6 2015 ms@suse.de
- Update README due to ssh key handling changes
* Fri Mar  6 2015 ms@suse.de
- config.ssh_private_key not used for vagrant builds
  Now that dice looks up the vagrant generated key there is
  no need for the Dicefile to specify the ssh pkey path
* Fri Mar  6 2015 ms@suse.de
- Fixed private key handling for buildsystem access
  vagrant has changed and will create its own key pair when the
  instance comes up. In order to use the right key dice look up
  the location of the generated private key and uses that for
  further ssh connections to the running instance
* Wed Mar  4 2015 ms@suse.de
- check_404_header only for remote uri
* Wed Mar  4 2015 ms@suse.de
- Bumb version to 0.5.3
* Tue Mar  3 2015 ms@suse.de
- Added support for rpm-dir repotype
  In addition to the support for plaindir repos, the check for
  the repo type was changed to use the type value from the kiwi
  config file instead of best guessing the type according to the
  presence of repo metadata files. Especially for repos without
  metadata like plaindirs this doesn't work well
* Tue Feb 17 2015 ms@suse.de
- Fixed use of dir:// uri type
  The check if the uri is a remote or local uri was missing
  in the repository type checker. This lead to a wrong location
  passed to the open call if the dir:// type was used
* Mon Feb 16 2015 ms@suse.de
- Added Uri class to control access
  Simple uri's like local paths or remote locations via http
  doesn't require a pre processing. However there are more
  complex uri's like the path to an iso which requires to
  loop mount the device prior to use it. It's also required to
  cleanup the state of such devices properly. It also makes
  sense to ask an Uri class if the resource is remote or
  local and maybe more useful messages can be passed to an
  Uri object in the future
* Fri Feb 13 2015 ms@suse.de
- Increase version to v0.5.2
* Fri Feb 13 2015 ms@suse.de
- Fixed use of local repositories
  In order to allow curl to load local files the
  mime type file:// must be prepended
* Thu Feb 12 2015 ms@suse.de
- Support dir:// and just path /... uri types
* Thu Feb  5 2015 ms@suse.de
- Update documentation
* Thu Feb  5 2015 ms@suse.de
- Fixed documentation references
* Thu Feb  5 2015 ms@suse.de
- Documentation style fixes
* Thu Feb  5 2015 ms@suse.de
- Update documentation
* Mon Jan  5 2015 ms@suse.de
- Added check_404_header method
  when using curl on a file which does not exist the response
  is a html encoded error code e.g 404 not found. The exit
  code of curl in that case is success but in fact this should
  be treated as an error
* Sun Jan  4 2015 ms@suse.de
- Make sure Command.run is used in repository_base
* Sun Jan  4 2015 ms@suse.de
- Added cleanup command
  cleanup build metadata. On build several metadata like the
  semaphore lock or vagrant instance metadata as well the
  caller history is created. This command allows to cleanup
  the data to its original state. So far only the semaphore
  cleanup has been implemented
* Fri Jan  2 2015 ms@suse.de
- Allow to set kiwi type as build option
* Thu Jan  1 2015 ms@suse.de
- Update rake task, delete static mkmf-rice.rb
* Thu Jan  1 2015 ms@suse.de
- Create semget lock id from a digest
  Using lock.sum is not safe. Instead a sha256 digest from
  the lock path is created and from there the sum value is
  used as id for semget
* Thu Jan  1 2015 ms@suse.de
- Allow lock release only if lock was set before
* Wed Dec 31 2014 ms@suse.de
- Use a local copy of mkmf-rice.rb to build Makefile
  For some reason loading of mkmf-rice with ruby in a
  buildservice chroot did not work. For now this
  workaround fixed the problem
* Wed Dec 31 2014 ms@suse.de
- Need a C++ compiler to build package
* Wed Dec 31 2014 ms@suse.de
- Build requires ruby-devel
* Wed Dec 31 2014 ms@suse.de
- Fixed build target
  ruby ./extconf.rb calls mkdir at a place without permissons
  when building in the buildservice
* Wed Dec 31 2014 ms@suse.de
- Added compile of semaphore to rake task
* Wed Dec 31 2014 ms@suse.de
- Use named semaphore for process synchronisation
  File base locking is not safe from race conditions
* Tue Dec 30 2014 ms@suse.de
- Added rebuild? method to BuildStatus class
  BuildStatus should determine if a rebuild is required
  The BuildTask just checks by sending this message to
  the status object
* Tue Dec 30 2014 ms@suse.de
- More flexible interface for build status
  checking for a class type as status type is not flexible.
  In addition the BuildStatus class should really know
  everything about the build status.
* Sun Dec 28 2014 ms@suse.de
- Found a duck
  making a decision by selecting for class type is not flexible
* Tue Dec 23 2014 ms@suse.de
- Delete no longer needed recipe test data
* Tue Dec 23 2014 ms@suse.de
- Better handling of Recipe class
  improve unit tests for Recipe class. change public interface
  to expose setup and validate methods and keep the constructor
  simple.
* Mon Dec 22 2014 ms@suse.de
- Make Recipe class better testable
* Mon Dec 22 2014 ms@suse.de
- Reduce class dependencies for Recipe and BuildTask
* Sun Dec 21 2014 ms@suse.de
- Remove argument order dependencies
* Sun Dec 21 2014 ms@suse.de
- Isolate dependencies
* Sat Dec 20 2014 ms@suse.de
- Update unit tests to all class changes
* Sat Dec 20 2014 ms@suse.de
- Cleanup BuildSystem class name
  Make sure the BuildSystem classes inherits from BuildSystemBase
* Sat Dec 20 2014 ms@suse.de
- Cleanup Connection class name
  Make sure the Connection classes inherits from ConnectionBase
* Sat Dec 20 2014 ms@suse.de
- Reduce class dependencies for Solver class
* Sat Dec 20 2014 ms@suse.de
- Don't test private methods
* Wed Dec 17 2014 ms@suse.de
- Cleanup Recipe class
  Make the interface more clear. The update method updates the
  checksum of the recipe which is clear by the name of the
  method it calls: writeRecipeChecksum.
  There should be no connection between a recipe and a job, but
  a recipe can check if something has changed in its configuration
  or metadata. So there is a method uptodate? which checks that
* Wed Dec 17 2014 ms@suse.de
- Cleanup Solver class
  The task for the Solver class is to solve packages
  against repositories and not to write the solver
  result to the recipe scan file. The latter belongs
  to the Recipe class
* Mon Dec 15 2014 ms@suse.de
- Fixed README
  log command has changed to be buildlog
* Mon Dec 15 2014 ms@suse.de
- Fixed inifile version lock down
  version 2.0.2 as currently in openSUSE works
* Sat Dec 13 2014 ms@suse.de
- Added dice history command
  it prints the dice command history for the given recipe
  and shows the result of the command with a timestamp as
  section name
* Fri Dec 12 2014 ms@suse.de
- Don't pass options as hash
  Instead make options available as OpenStruct instance
  global to the Dice namespace
* Fri Dec 12 2014 ms@suse.de
- Make the logger an instance of the Logger class
  in addition write the logfile in ini format
* Thu Dec 11 2014 ms@suse.de
- Added dice-rpmlintrc as source to spec file
* Wed Dec 10 2014 ms@suse.de
- Fixed spec template
  Source location is local since dice is not yet
  available on rubygems.org
* Wed Dec 10 2014 ms@suse.de
- OO Cleanup
  Hide instance variables, use attr_reader and
  remove obsolete self written accessor methods
* Tue Dec  9 2014 ms@suse.de
- Added Copyright comment
* Tue Dec  9 2014 ms@suse.de
- Update README
* Wed Nov 26 2014 ms@suse.de
- Cleanup exception handling
  Use one central place to define exceptions for error
  conditions and build states
* Fri Nov 21 2014 ms@suse.de
- Fixed cleanup screen job call
  unknown private method called, left over from last change
* Fri Nov 21 2014 ms@suse.de
- Fixed use of open-uri
  using File.open will always open a file not a uri
* Fri Nov 21 2014 ms@suse.de
- Update 13.2 recipe to use update repo
* Fri Nov 21 2014 ms@suse.de
- Added information about result in status output
* Fri Nov 21 2014 ms@suse.de
- Add Gemfile.lock to gitignore
* Fri Nov 14 2014 ms@suse.de
- Update unit tests for Solver
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for Solver
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for SuSERepository
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for RpmMdRepository
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for RepositoryFactory
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for RepositoryBase
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for KiwiUri
* Fri Nov 14 2014 ms@suse.de
- Added unit tests for KiwiConfig
* Fri Nov 14 2014 ms@suse.de
- Make sure /var/tmp/kiwi/satsolver is created if not existent
* Thu Nov 13 2014 ms@suse.de
- Docker build requires to run in privileged mode
* Thu Nov 13 2014 ms@suse.de
- Moved ssh startup fixes into the docker build box build on BS
* Thu Nov 13 2014 ms@suse.de
- Added example config for docker use in suse-13.1-JeOS/Vagrantfile
* Wed Nov 12 2014 ms@suse.de
- Update test recipe build host connection
* Wed Nov 12 2014 ms@suse.de
- Append log data
  in case of a raise the raise message was written to
  a logfile by opening it as new file. Thus log information
  from former commands e.g kiwi was wiped. The log information
  should be appended
* Mon Nov  3 2014 ms@suse.de
- delete TODO, handle issues on github
* Wed Oct 29 2014 ms@suse.de
- Fixed factories to be real factories
* Wed Oct 29 2014 ms@suse.de
- rename repository class to RepositoryFactory
* Mon Oct 27 2014 ms@suse.de
- Update 13.2 recipe, ssh key path should point to homedir
* Mon Oct 27 2014 ms@suse.de
- Added unit test templates for new solver and repos
  tests for them are still missing though
* Mon Oct 27 2014 ms@suse.de
- Use http URL for factory because the URI translator in
  kiwi_uri does not yet know about full obs:// uri style
* Mon Oct 27 2014 ms@suse.de
- Added support for native solver, no kiwi --info required anymore
* Fri Oct 24 2014 jmassaguerpla@suse.de
- update docs
  add the "dice log" option in the README.md file
* Thu Oct 23 2014 jmassaguerpla@suse.de
- fix issue #3 : dice ssh command
  This commit adds the "dice ssh" command.
* Thu Oct 23 2014 ms@suse.de
- Use abstract_method gem
* Wed Oct 22 2014 ms@suse.de
- Fixed spec file, require base kiwi for solver with
* Wed Oct 22 2014 ms@suse.de
- Fixed typo
* Wed Oct 22 2014 ms@suse.de
- Update docs
* Wed Oct 22 2014 ms@suse.de
- Update class graph
* Wed Oct 22 2014 ms@suse.de
- Update example 13.2 recipe to use btrfs
* Tue Oct 21 2014 ms@suse.de
- Don't test private methods
* Tue Oct 21 2014 ms@suse.de
- Set primary build for SLE12 example to vmx
* Tue Oct 21 2014 ms@suse.de
- Better way to get IP and Port of vagrant machine
* Tue Oct 21 2014 ms@suse.de
- Add example Vagrantfile which works for virtualbox and libvirt
* Tue Oct 21 2014 ms@suse.de
- Fixed scheduler
* Tue Oct 21 2014 ms@suse.de
- Let BuildTask inherit from Solver
* Mon Oct 20 2014 ms@suse.de
- Update unit tests
* Mon Oct 20 2014 ms@suse.de
- Restructure Recipe class
* Sun Oct 19 2014 ms@suse.de
- Update dot graph style
* Sun Oct 19 2014 ms@suse.de
- Update dot graph
* Sun Oct 19 2014 ms@suse.de
- Update dot graph
* Sun Oct 19 2014 ms@suse.de
- Update dot graph
* Thu Oct 16 2014 ms@suse.de
- Update docs
* Thu Oct 16 2014 ms@suse.de
- Fixed status information for running builds
* Thu Oct 16 2014 ms@suse.de
- Put class name as prefix for info messages
* Thu Oct 16 2014 ms@suse.de
- Put exec calls as string to allow cut&paste
* Mon Oct 13 2014 ms@suse.de
- There is no need to lock the status call
* Mon Oct 13 2014 ms@suse.de
- Set host buildsystem locks in /tmp
* Mon Oct 13 2014 ms@suse.de
- Added correct status result for running or locked
* Mon Oct 13 2014 ms@suse.de
- Added simple --show option for log command
* Mon Oct 13 2014 ms@suse.de
- Don't show that a log exists in the status message
  In addition store the build log file as build.log and not
  as build_error.log because it is no longer removed it could
  contain a successful build log as well
* Mon Oct 13 2014 ms@suse.de
- Don't remove build log
* Sun Oct 12 2014 ms@suse.de
- Use global worker host lock file
* Thu Oct  9 2014 ms@suse.de
- Distinguish state between BuildRunning and BuildWorkerBusy
* Thu Oct  9 2014 ms@suse.de
- Fix is_busy? for host_build_system. in this case the host is
  busy if there is either a lock file or a kiwi process runs on
  the host
* Thu Oct  9 2014 ms@suse.de
- Use kiwi terminal logging and send the logfile data directly
  while the process runs
* Wed Oct  8 2014 ms@suse.de
- Fixed screen info call
* Wed Oct  8 2014 ms@suse.de
- Use google for building, Amazon is currently disabled for billing reasons
* Wed Oct  8 2014 ms@suse.de
- Check for screen jobs and print only active ones in status output
* Tue Oct  7 2014 ms@suse.de
- Cleanup constants
* Tue Oct  7 2014 ms@suse.de
- Force ssh to non-interactive mode
* Tue Oct  7 2014 ms@suse.de
- Force rsync into non-interactive mode
* Tue Oct  7 2014 ms@suse.de
- append screen session names to job instead of overwriting
* Tue Oct  7 2014 ms@suse.de
- Use screen in the build scheduler to run jobs
* Tue Oct  7 2014 ms@suse.de
- buildlog should be build_error.log
* Tue Oct  7 2014 ms@suse.de
- Use sudo -s
* Tue Oct  7 2014 ms@suse.de
- Try -T option for ssh when calling kiwi --build
* Mon Oct  6 2014 ms@suse.de
- Let build scheduler call dice build
* Mon Oct  6 2014 ms@suse.de
- No strict host key checking
* Mon Oct  6 2014 ms@suse.de
- Update example recipe structure
* Mon Oct  6 2014 ms@suse.de
- Change status message to display error message in any case
* Mon Oct  6 2014 ms@suse.de
- Update gitignore list
* Mon Oct  6 2014 ms@suse.de
- Added another worker host from the Google Compute Engine cloud
* Sun Oct  5 2014 ms@suse.de
- Fixed unit tests
* Sun Oct  5 2014 ms@suse.de
- Fixed location of lock file and release of lock in case of error
* Sun Oct  5 2014 ms@suse.de
- Update status call to know about last build error if any
* Sun Oct  5 2014 ms@suse.de
- Make sure a successful build remove any previos build_error.log file
* Sun Oct  5 2014 ms@suse.de
- Write a build_error.log in case of any raise for a build task
* Sun Oct  5 2014 ms@suse.de
- Move all metadata into a .dice directory
* Sun Oct  5 2014 ms@suse.de
- Store build metadata in files with recipe dir as prefix
* Sat Oct  4 2014 ms@suse.de
- Add startup message on schedule
* Sat Oct  4 2014 ms@suse.de
- Better error messages
  Use clean prefix for each message
* Sat Oct  4 2014 ms@suse.de
- Better error message
* Sat Oct  4 2014 ms@suse.de
- Better error messages
* Fri Oct  3 2014 ms@suse.de
- Added schedule command
* Fri Oct  3 2014 ms@suse.de
- Fixed locking
* Thu Oct  2 2014 ms@suse.de
- Added a simple locking mechanism
* Thu Oct  2 2014 ms@suse.de
- No file glob in cheetah call
* Thu Oct  2 2014 ms@suse.de
- Fix default permissions for key files
* Thu Oct  2 2014 ms@suse.de
- Forgot to add key to filelist
* Thu Oct  2 2014 ms@suse.de
- Fixed key handling for normal user and adapt docs
* Thu Oct  2 2014 ms@suse.de
- Added vagrant key to package
* Wed Oct  1 2014 ms@suse.de
- Update docs
* Wed Oct  1 2014 ms@suse.de
- Update docs
* Wed Oct  1 2014 ms@suse.de
- Fixed gemspec
* Wed Oct  1 2014 ms@suse.de
- Update .gitignore
* Wed Oct  1 2014 ms@suse.de
- Update recipes
* Wed Oct  1 2014 ms@suse.de
- Added example recipes to package
* Wed Oct  1 2014 ms@suse.de
- Fixed bash completion to use correct dice binary
* Wed Oct  1 2014 ms@suse.de
- Added bash completion to package
* Wed Oct  1 2014 ms@suse.de
- Fixed gemspec
  pathname and fileutils are ruby core
* Wed Oct  1 2014 ms@suse.de
- Update changes generator
* Wed Oct  1 2014 ms@suse.de
- Update package files
* Wed Oct  1 2014 ms@suse.de
- xz compression is a time consuming task, we want the results fast
* Wed Oct  1 2014 ms@suse.de
- Added --force option for build and use the kiwi bundler
* Tue Sep 30 2014 ms@suse.de
- Added bash completion file
* Tue Sep 30 2014 ms@suse.de
- Update docs
* Tue Sep 30 2014 ms@suse.de
- Add ec2 worked in DiceFile
* Tue Sep 30 2014 ms@suse.de
- Add log message for halt on host_build_system
* Tue Sep 30 2014 ms@suse.de
- End messages with a CR
* Tue Sep 30 2014 ms@suse.de
- Send HUP not KILL
* Tue Sep 30 2014 ms@suse.de
- Log improvements
* Mon Sep 29 2014 ms@suse.de
- Better logging
* Mon Sep 29 2014 ms@suse.de
- Update unit tests
* Mon Sep 29 2014 ms@suse.de
- Added process id to state messages
* Mon Sep 29 2014 ms@suse.de
- Added process ID to exception information
* Mon Sep 29 2014 ms@suse.de
- Print process ID in log messages
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Mon Sep 29 2014 ms@suse.de
- Fixed doc references
* Mon Sep 29 2014 ms@suse.de
- Fixed doc references
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Mon Sep 29 2014 ms@suse.de
- Update docs
* Thu Sep 25 2014 ms@suse.de
- Remove Vagrantfile from 13.1-JeOS we build that example with a cloud worker
* Wed Sep 24 2014 ms@suse.de
- Use official build box in EC2
* Tue Sep 23 2014 ms@suse.de
- Added packaging task
* Tue Sep 23 2014 ms@suse.de
- Update dot graph
* Tue Sep 23 2014 ms@suse.de
- Simplify Solver task
* Tue Sep 23 2014 ms@suse.de
- Cleanup build_task and connection_task
* Mon Sep 22 2014 ms@suse.de
- Better use factory for job and connection
* Mon Sep 22 2014 ms@suse.de
- Added status command
* Sun Sep 21 2014 ms@suse.de
- Update unit tests
* Sun Sep 21 2014 ms@suse.de
- Use own class for handling connections to build system
* Sat Sep 20 2014 ms@suse.de
- Call a cleanup method for the build task on signal
* Fri Sep 19 2014 ms@suse.de
- Fixed build log pid detection if multiple processes accesses the buildlog
* Fri Sep 19 2014 ms@suse.de
- Fixed sle12 recipe, syntax bug in VagrantFile
* Fri Sep 19 2014 ms@suse.de
- Don't globally stub puts
* Wed Sep 17 2014 ms@suse.de
- Use factory class to build BuildSystem variants, add dot graph
  for class layout
* Wed Sep 17 2014 ms@suse.de
- Reorganize some names for better reading
* Wed Sep 17 2014 ms@suse.de
- Don't take Dicefile into account for build update
* Wed Sep 17 2014 ms@suse.de
- Fixed build logger pid detection for process logging to /buildlog
  on the machine running the job
* Tue Sep 16 2014 ms@suse.de
- Added log command
* Tue Sep 16 2014 ms@suse.de
- Update unit tests
* Tue Sep 16 2014 ms@suse.de
- No sudo required for solver with new kiwi
* Mon Sep 15 2014 ms@suse.de
- README style changes
* Mon Sep 15 2014 ms@suse.de
- Update README
* Sun Sep 14 2014 ms@suse.de
- Implemented host build system support
* Sat Sep 13 2014 ms@suse.de
- Added custom Dicefile support
* Sat Sep 13 2014 ms@suse.de
- Allow Job to receive optional user and private key
* Sat Sep 13 2014 ms@suse.de
- Adapt class layout to allow job on custom host
* Sat Sep 13 2014 ms@suse.de
- Prepare job class to be able to use custom ssh user and key
* Wed Sep 10 2014 ms@suse.de
- Update unit tests for non covered classes
* Wed Sep 10 2014 ms@suse.de
- Use double for testing
* Tue Sep  9 2014 ms@suse.de
- Cleanup info scan
* Tue Sep  9 2014 ms@suse.de
- Added logger and BuildTask
* Wed Sep  3 2014 ms@suse.de
- Unit tests for Solve class
* Wed Sep  3 2014 ms@suse.de
- Unit tests for Solve class
* Wed Sep  3 2014 ms@suse.de
- Unit tests
* Wed Sep  3 2014 ms@suse.de
- Added Solve class to allow tracking of repo changes
* Wed Sep  3 2014 ms@suse.de
- Split up system prebuild checks
* Wed Sep  3 2014 ms@suse.de
- Add use of digests
* Tue Sep  2 2014 ms@suse.de
- Unit tests for missing methods
* Tue Sep  2 2014 ms@suse.de
- Added methods to build and compare digest from recipe
* Mon Sep  1 2014 ms@suse.de
- Update Vagrantfile's
  add memory setup (1G)
* Mon Sep  1 2014 ms@suse.de
- Update README
* Sat Aug 30 2014 ms@suse.de
- Change default machine access method to use vagrant forwarded ssh port
  Currently the code set this mode via an instance variable
  names use_ssh_forwarding. This might be a config file option
  later
* Sat Aug 30 2014 ms@suse.de
- Added SLE12 recipe
  Use virtualbox for building, seems to have better performance
  compared to libvirt
* Sat Aug 30 2014 ms@suse.de
- Update ignore file
* Sat Aug 30 2014 ms@suse.de
- Added get_port method
* Fri Aug 29 2014 ms@suse.de
- Fixed unit test
  stub open
* Fri Aug 29 2014 ms@suse.de
- Fixed location of result tarball
  don't store inside of the recipe because that gets provisioned to the box
* Fri Aug 29 2014 ms@suse.de
- Unit tests for job
* Thu Aug 28 2014 ms@suse.de
- Complete build_systems tests
* Thu Aug 28 2014 ms@suse.de
- Follup up on test completion
* Thu Aug 28 2014 ms@suse.de
- Store information about current working dir and reset on halt
* Wed Aug 27 2014 ms@suse.de
- Added rake task for unit tests
* Wed Aug 27 2014 ms@suse.de
- All this should be done test driven
* Wed Aug 27 2014 ms@suse.de
- return not needed
* Tue Aug 26 2014 ms@suse.de
- Use ssh directly instead of vagrant ssh
* Tue Aug 26 2014 ms@suse.de
- Add get_result method
* Tue Aug 26 2014 ms@suse.de
- Ignore buildlog in git
* Tue Aug 26 2014 ms@suse.de
- Don't use kiwi bundler for performance reasons
* Mon Aug 25 2014 ms@suse.de
- added buildsystem and job classes
* Mon Aug 25 2014 ms@suse.de
- update example Vagrantfile to set default provider using ENV
* Mon Aug 25 2014 ms@suse.de
- put a warning that all this is under construction
